// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef GRANTLEETHEME_VERSION_H
#define GRANTLEETHEME_VERSION_H

#define GRANTLEETHEME_VERSION_STRING "6.6.80"
#define GRANTLEETHEME_VERSION_MAJOR 6
#define GRANTLEETHEME_VERSION_MINOR 6
#define GRANTLEETHEME_VERSION_PATCH 80
#define GRANTLEETHEME_VERSION ((6<<16)|(6<<8)|(80))

#endif
